@@ -60,6 +60,7 @@ type ClientConfig struct {
 	ClientID               string
 	ClientSecret           string
 	Scopes                 []string
+	Audience               []string
 	AuthMethod             string
 	PKCE                   bool
 	PAR                    bool
@@ -84,6 +85,7 @@ type ClientConfig struct {
 	TLSCert                string
 	TLSKey                 string
 	TLSRootCA              string
+	Timeout                time.Duration
 	DPoP                   bool
 	Claims                 string
 }
@@ -209,6 +211,9 @@ func WaitForCallback(clientConfig ClientConfig, serverConfig ServerConfig, hc *h
 	}
 
 	srv.Addr = redirectURL.Host
+	if redirectURL.Path == "" {
+		redirectURL.Path = "/"
+	}
 
 	http.HandleFunc(redirectURL.Path, func(w http.ResponseWriter, r *http.Request) {
 		defer func() {
@@ -356,8 +361,14 @@ func RequestToken(
 	}
 
 	switch cconfig.GrantType {
-	case ClientCredentialsGrantType, PasswordGrantType, RefreshTokenGrantType, JWTBearerGrantType:
-		request.Form.Set("scope", strings.Join(cconfig.Scopes, " "))
+	case ClientCredentialsGrantType, PasswordGrantType, RefreshTokenGrantType, JWTBearerGrantType, TokenExchangeGrantType:
+		if len(cconfig.Scopes) > 0 {
+			request.Form.Set("scope", strings.Join(cconfig.Scopes, " "))
+		}
+
+		if len(cconfig.Audience) > 0 {
+			request.Form.Set("audience", strings.Join(cconfig.Audience, " "))
+		}
 	}
 
 	switch cconfig.GrantType {
